#
# spec file for package lxqt2-build-tools
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name lxqt-build-tools
Name:           lxqt2-build-tools
Version:        2.1.0
Release:        1.1
Summary:        Core build tools for LXQt
License:        BSD-3-Clause
URL:            https://github.com/lxqt/lxqt-build-tools
Source0:        %{url}/releases/download/%{version}/%{_name}-%{version}.tar.xz
Source1:        %{url}/releases/download/%{version}/%{_name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  cmake >= 3.16.0
BuildRequires:  pkgconfig
BuildRequires:  cmake(Qt6Core) >= 6.6
BuildRequires:  pkgconfig(glib-2.0) >= 2.50
BuildArch:      noarch

%description
This package provides several tools needed to build LXQt itself as well as
other components maintained by the LXQt project.

%package devel
Summary:        Tools for building lxqt
Requires:       cmake(Qt6Core)

%description devel
This package provides several tools needed to build LXQt itself as well as
other components maintained by the LXQt project.

These tools used to be spread over the repositories of various other
components and were summarized to ease dependency management. So far many
components, in particular [liblxqt](https://github.com/lxde/liblxqt), were
representing a build dependency without being needed themselves but only
because their repository was providing a subset of the tools which are now
summarized here. So the use of this repository will reduce superfluous and
bloated dependencies.

%prep
%autosetup -p1 -n %{_name}-%{version}

%build
%cmake
%cmake_build

%install
%cmake_install

%files devel
%doc AUTHORS CHANGELOG README.md
%license BSD-3-Clause
%{_datadir}/cmake/
%{_bindir}/lxqt2-transupdate

%changelog
* Wed Nov  6 2024 Андрей Алыпов <and.november@opensuse.org>
- Update to version 2.1.0:
  * Pre-release changes (#100)
  * Pre-release changes (#98)
  * FindInstallConfigPath: Change when printing info about ETC_XDG_DIR setting (#97)
  * Update minimum versions (#94)
  * Qt6TranslationLoader.cpp.in: use QLibraryInfo::path() (#93)
  * Initial port to Qt6 (#77)
  * Pre-release changes (#85)
  * Bump the minimum compatibility level to C++17.
  * Pre-release changes (#82)
* Wed Apr 17 2024 Shawn Dunn <sfalken@opensuse.org>
- Update to 2.0.0
  * Ported to Qt6 with the new project name lxqt2-build-tools, such
    that the Qt5-based version 0.13.0 can be installed alongside it.
- Specfile modernization and cleanup
* Sat Apr 15 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 0.13.0
  * Bumped minimum compatibility level to C++17
- Remove lxqt-build-tools-0.12.0-cpp17.patch
* Tue Feb 14 2023 Michael Vetter <mvetter@suse.com>
- boo#1208217: Bump required C++ version
  See also: gh/lxqt/lxqt-config#903
  Add lxqt-build-tools-0.12.0-cpp17.patch
* Sat Nov  5 2022 Shawn Dunn <sfalken@cloverleaf-linux.org>
- Update to 0.12.0
  * Support absolute `CMAKE_INSTALL_{INCLUDE,LIB}DIR` in
    `LXQtCreatePkgConfigFile'
  * Use `gdesktopappinfo.h` to find gio-unix-2.0 in
    `FindGLIB.cmake`
  * Drop use of `-Bsymbolic` in `LXQtCompilerSettings`
- Remove lxqt-build-tools-symbolic.patch
- Remove 4991811-fix-FindGLIB.cmake.patch
* Thu Sep 29 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add patch to fix libqt5xdg with latest glib-2.0:
  * 4991811-fix-FindGLIB.cmake.patch
* Mon Aug 29 2022 Michael Vetter <mvetter@suse.com>
- bsc#1195421: Add lxqt-build-tools-symbolic.patch
  Thanks to Fabian Vogt
* Wed Apr 20 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 0.11.0
  * Fixed build scripts for GLib 2.71.1
* Fri Nov  5 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.10.0:
  * Set the minimum required version of Qt to 5.15.
* Fri Apr 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.9.0:
  * A CMake FindXTerm module is added.
* Wed Nov  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.8.0:
  * Removed version checks for some LXQt dependencies.
  * Added a Fontconfig CMake find module.
  * Suppressed warning about find_package_handle_standard_args
    package name mismatch.
* Fri Apr 24 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 0.7.0
  * String casts are forbidden explicitly.
  * CMake find modules are added for some xdg-utils tools.
  * The minimum Qt version is incremented to 5.10.
* Thu Jan 31 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.6.0:
  * Introduced lxqt-transupdate for translation updates
  * Set cmake_minimum_required to 3.1.0
  * Consider QT_SELECT - some distributions use this tool
  * Drop 0X and 11 support, require c++14
  * Removed obsolete FindFm module
* Tue May 22 2018 mvetter@suse.com
- Update to 0.5.0:
  * LXQtCompilerSettings: Set CMAKE_C_VISIBILITY_PRESET to hidden
  * Don’t allow Qt foreach/Q_FOREACH
  * Require Qt 5.7.1
  * Adds a FindXKBCommon CMake module
  * Adds ECMFindModuleHelpers CMake module
* Mon Oct 23 2017 mvetter@suse.com
- Update to 0.4.0:
  * Bump version to 0.4.0
  * Added needed versions
  * remove version set from LXQtConfigVars.in
  * Move LXQt version to liblxqt
  * Fixes a FTBFS with superbuild mode
  * Adds a FindExif module
  * LXQtCompilerSettings: Fixes a typo in diagnostics-color
  * Adds (Ninja) colored diagnostics for GCC (>=4.9)
  * Enable strict iterators for debug builds
* Tue Jun 20 2017 alarrosa@suse.com
- Update to 0.3.2
  * Bump version to 0.3.2 - finally the build tools are arch: all (#15)
  * Warnings (#16)
  * Remove arched bits from version.cmake-file (#14)
  * Fixed missing point in version string
- Update Source URLs
* Sat Mar  4 2017 sfalken@opensuse.org
- Update Source URLs
- Normalize .spec file to match with version in X11:LXQt:git
* Sat Mar  4 2017 mvetter@suse.com
- Install BSD License file
* Thu Feb 23 2017 sfalken@opensuse.org
- Initial Commit.   New Package that will be needed for building
  lxqt going forward.
